# Changelog

(This file may not be historically complete, as it is a recent addition to the project).


## [1.0.0-alpha] - 2019-07-23

- Updated to work with CKAN 2.9.0a, e.g.:
    - uses toolkit wherever possible
    - references to Pylons removed
- Standardised README, CHANGELOG, setup.py and .github files to match other Museum extensions